==> miktex-2.9.7250.tar.xz: miktex-2.9.7250/Programs/DviWare/dvisvgm/source/src/SVGSingleCharTextHandler.hpp <==
/*************************************************************************
** SVGSingleCharTextHandler.hpp                                         **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef SVGSINGLECHARTEXTHANDLER_HPP
#define SVGSINGLECHARTEXTHANDLER_HPP

#include "SVGCharHandler.hpp"


class SVGSingleCharTextHandler : public SVGCharTextHandler {
	public:
		SVGSingleCharTextHandler (bool createStyleElements) : SVGCharTextHandler(createStyleElements) {}
		void appendChar (uint32_t c, double x, double y) override;
};

#endif

==> miktex-2.9.7400.tar.xz: miktex-2.9.7400/Programs/DviWare/dvisvgm/source/src/SVGSingleCharTextHandler.hpp <==
/*************************************************************************
** SVGSingleCharTextHandler.hpp                                         **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2020 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef SVGSINGLECHARTEXTHANDLER_HPP
#define SVGSINGLECHARTEXTHANDLER_HPP

#include "SVGCharHandler.hpp"


class SVGSingleCharTextHandler : public SVGCharTextHandler {
	public:
		explicit SVGSingleCharTextHandler (bool createStyleElements) : SVGCharTextHandler(createStyleElements) {}
		void appendChar (uint32_t c, double x, double y) override;
};

#endif
